package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(.``````````0```````
M`*%0``````!``#@`"`!``!8`%0````8````$`````````$``````````0```
M``````!``````````<`````````!P``````````(`````P````0````````"
M``````````(``````````@``````````&``````````8``````````$````!
M````!0```````````````````````````````````````)<(````````EP@`
M```````0``````$````&````````F_````````"K\````````*OP````````
M!(@````````4Z````````!```````@````8```````"<$````````*P0````
M````K!`````````!H`````````&@``````````AD=.50````!````````)$<
M````````D1P```````"1'`````````#4`````````-0`````````!&1TY5$`
M```&````````````````````````````````````````````````````````
M```````09'3E4@````0```````";\````````*OP````````J_`````````$
M$`````````00``````````$O;&EB+VQD+6UU<VPM<S,Y,'@N<V\N,0`````1
M````10````0````(@`1`!0`0$""$`(:`!!``*`D$``D``"&""`($ND$8@(@`
M````````10```$D```!-````3@```%0```!5````5@````````!8````60``
M``````!:````6P```%T``````````'R:?VH.[]/J+4?>SA_?Q6^VF\4N#O&-
MN'S49-0.Y/\A'%AQV6!LH?HL/^7";XL!LH?7^D(!QD?B?)+CN](\PU5FS*]G
MTW`'B.S514/MVV(SS"6,%9N<J7\*`J?@4)X::TG[X*,`````````````````
M`````````````````````P``!P```````!>8```````````````!$@``````
M```````````````````````)$0````````````````````````````&N$0``
M``````````````````````````%*$@`````````````````````````````0
M$@````````````````````````````&'$@``````````````````````````
M```8$@`````````````````````````````?$@``````````````````````
M``````&[$@````````````````````````````&3$@``````````````````
M```````````H(`````````````````````````````+)(0``````````````
M``````````````!`$@````````````````````````````!&$@``````````
M``````````````````)Y$@````````````````````````````*Y$@``````
M``````````````````````'A$@````````````````````````````!-$@``
M``````````````````````````)G$@````````````````````````````!4
M$@````````````````````````````!<$@``````````````````````````
M``)0$@````````````````````````````!D$@``````````````````````
M``````!J$@````````````````````````````!S(```````````````````
M``````````*R$@````````````````````````````"/$@``````````````
M``````````````"4$@````````````````````````````',$0``````````
M``````````````````)N$@````````````````````````````(.$@``````
M``````````````````````";$@````````````````````````````(`$@``
M``````````````````````````,-$@````````````````````````````+(
M$0````````````````````````````(R$@``````````````````````````
M``*8$@````````````````````````````+*$0``````````````````````
M``````"B$@````````````````````````````*!$@``````````````````
M``````````%8$@````````````````````````````"K(@``````````````
M``````````````"Z(`````````````````````````````#0$@``````````
M``````````````````*)$@````````````````````````````(>$@``````
M``````````````````````#5$@````````````````````````````#;(```
M``````````````````````````);$@````````````````````````````#U
M$@````````````````````````````%X$@``````````````````````````
M``#Z$@````````````````````````````)`$@``````````````````````
M``````%G$@````````````````````````````$`$@``````````````````
M``````````$1$@````````````````````````````'<$@``````````````
M``````````````!E$@````````````````````````````'M$@``````````
M``````````````````(G$@````````````````````````````*1$@``````
M``````````````````````$7$@````````````````````````````*J$@``
M``````````````````````````$K$@````````````````````````````'7
M$@````````````````````````````$R$@``````````````````````````
M``%#$@````````````````````````````*E$@``"0```````![@````````
M`?P```&H$@``"@```````%)P``````````(```-/$@``"0```````#`X````
M````!D(```/[$@``"0```````#D(`````````&@```,L$@``"0```````"HP
M``````````8```.Y$@``!P```````!>8``````````(```-R$@``"0``````
M`#:``````````H0```/?$@``"0```````"HX`````````=8```.J$```$P``
M`````+!X``````````````,]$@``"0```````"^(`````````*P```-<$@``
M"0```````"B(`````````#P```-D$@``"0```````"[H`````````&X```.(
M$@``"0```````$^P`````````4X```.=$@``"0```````"P0`````````"(`
M``/V$```$P```````,#8``````````````+R$@``"0```````"$0````````
M`#P```._$@``"0```````"PX`````````2(```.3$0``$@```````+!P````
M``````@```/8$```$@```````+!X``````````````.O$@``"0```````"#@
M``````````````.V$@``"0```````$]``````````&P```+[$@``"0``````
M`"]8`````````"P```,6$@``"0```````"DH`````````00```/L$@``"0``
M`````%$``````````18```/+$@``"0```````"U@`````````8(`;W!E;F1I
M<@!S=&1E<G(`<F5A;&QO8P!A8V-E<W,`<VYP<FEN=&8`7U]D97)E9VES=&5R
M7V9R86UE7VEN9F\`;'-E96L`9V5T<&ED`'5N;&EN:P!M96UM;W9E`'-T<FYC
M;7``;'-T870`8VQO<V5D:7(`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE
M`&]P96X`<W1R<W1R`'-T<F-H<@!R96%D;&EN:P!?7V-X85]F:6YA;&EZ90!?
M7W)E9VES=&5R7V9R86UE7VEN9F\`97AI=`!C;&]S90!?251-7W)E9VES=&5R
M5$U#;&]N951A8FQE`')E860`<FUD:7(`7U]E<G)N;U]L;V-A=&EO;@!M:V1I
M<@!P=&AR96%D7V=E='-P96-I9FEC`&UE;6-P>0!?7W-T86-K7V-H:U]F86EL
M`&=E='5I9`!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F
M;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A
M:U]N;V-O;G1E>'0`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA
M9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O
M<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?
M<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`
M<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!R96%D
M9&ER`'-T<FYC<'D`9G!R:6YT9@!S=')T;VL`7U]L:6)C7W-T87)T7VUA:6X`
M<W!R:6YT9@!S=')D=7``<'1H<F5A9%]A=&9O<FL`7U]E;G9I<F]N`&QI8G!E
M<FPN<V\`;&EB8RYM=7-L+7,S.3!X+G-O+C$`7W-T87)T7V,`9V5T7W5S97)N
M86UE7V9R;VU?9V5T<'=U:60`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]C
M=7)R96YT7V5X96,`<&%R7W-E='5P7VQI8G!A=&@`<&%R7VUK=&UP9&ER`'AS
M7VEN:70`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`<VAA
M7W5P9&%T90!M>5]P87)?<&P`<&%R7V)A<V5N86UE`%]?8G-S7W-T87)T`'-H
M85]I;FET`'!A<E]D:7)N86UE`'!A<E]I;FET7V5N=@!?961A=&$`<&%R7V9I
M;F1P<F]G`'-H85]F:6YA;`!?96YD`'!A<E]C;&5A;G5P`"]U<W(O;&EB+W!E
M<FPU+V-O<F5?<&5R;"]#3U)%`````````````*^(``````````P````````>
MX````````*^@``````````P```````!2<````````*^X``````````P`````
M```7F````````+````````````P```````"P`````````+`0``````````P`
M``````!2D@```````+`8``````````P```````!2F````````+`H````````
M``P```````!2F@```````+`P``````````P```````!2G@```````+`X````
M``````P```````!2I@```````+!```````````P```````!3$@```````+!(
M``````````P```````!2K@```````+!8``````````P```````!2L@``````
M`+!@``````````P```````!2N````````+!P``````````P```````!5;@``
M`````*^0`````P````H``````````````````*^8````!`````H`````````
M`````````*^H````#`````H``````````````````*^P````&@````H`````
M`````````````*_`````'@````H``````````````````*_(````)P````H`
M`````````````````*_0````*P````H``````````````````*_8````+```
M``H``````````````````*_@````,0````H``````````````````*_H````
M-@````H``````````````````*_P````-P````H``````````````````*_X
M````/`````H``````````````````*W(`````@````L`````````````````
M`*W0````!0````L``````````````````*W8````!@````L`````````````
M`````*W@````!P````L``````````````````*WH````"`````L`````````
M`````````*WP````"0````L``````````````````*WX````"@````L`````
M`````````````*X`````"P````L``````````````````*X(````#`````L`
M`````````````````*X0````#@````L``````````````````*X8````#P``
M``L``````````````````*X@````$`````L``````````````````*XH````
M$0````L``````````````````*XP````$@````L``````````````````*XX
M````$P````L``````````````````*Y`````%`````L`````````````````
M`*Y(````%0````L``````````````````*Y0````%@````L`````````````
M`````*Y8````%P````L``````````````````*Y@````&`````L`````````
M`````````*YH````&0````L``````````````````*YP````&P````L`````
M`````````````*YX````'`````L``````````````````*Z`````'0````L`
M`````````````````*Z(````'P````L``````````````````*Z0````(```
M``L``````````````````*Z8````(0````L``````````````````*Z@````
M(@````L``````````````````*ZH````(P````L``````````````````*ZP
M````)0````L``````````````````*ZX````)@````L`````````````````
M`*[`````*`````L``````````````````*[(````*0````L`````````````
M`````*[0````*@````L``````````````````*[8````*P````L`````````
M`````````*[@````+`````L``````````````````*[H````+0````L`````
M`````````````*[P````+@````L``````````````````*[X````+P````L`
M`````````````````*\`````,`````L``````````````````*\(````,@``
M``L``````````````````*\0````,P````L``````````````````*\8````
M-`````L``````````````````*\@````-0````L``````````````````*\H
M````.`````L``````````````````*\P````.0````L`````````````````
M`*\X````.@````L``````````````````*]`````.P````L`````````````
M`````*](````/0````L``````````````````*]0````/@````L`````````
M`````````*]8````/P````L``````````````````*]@````0`````L`````
M`````````````*]H````00````L``````````````````*]P````0@````L`
M`````````````````*]X````0P````L``````````````````*^`````1```
M``L``````````.OO\'``)+D$``^G^_]@XP#P```DP.4```5RP.4``!TSZ^_Q
M$``$!_[C$/`X`"3`$```2O72!_`P$`CC$!`0``0'\0<`!P`'`,`0``!*].,0
M$```!`?Q#1#C$!`,`!3`]/___^4`````P!```$KHXQ`0```$!_$-$.,0$`P`
M%,#T____U0```!C`$```2MSC$!````0'\0T0XQ`0#``4P/3____%````,,`0
M``!*T.,0$```!`?Q#1#C$!`,`!3`]/___[4```!(P!```$K$XQ`0```$!_$-
M$.,0$`P`%,#T____I0```&#`$```2KCC$!````0'\0T0XQ`0#``4P/3___^5
M````>,`0``!*K.,0$```!`?Q#1#C$!`,`!3`]/___X4```"0P!```$J@XQ`0
M```$!_$-$.,0$`P`%,#T____=0```*C`$```2I3C$!````0'\0T0XQ`0#``4
MP/3___]E````P,`0``!*B.,0$```!`?Q#1#C$!`,`!3`]/___U4```#8P!``
M`$I\XQ`0```$!_$-$.,0$`P`%,#T____10```/#`$```2G#C$!````0'\0T0
MXQ`0#``4P/3___\U```!",`0``!*9.,0$```!`?Q#1#C$!`,`!3`]/___R4`
M``$@P!```$I8XQ`0```$!_$-$.,0$`P`%,#T____%0```3C`$```2DSC$!``
M``0'\0T0XQ`0#``4P/3___\%```!4,`0``!*0.,0$```!`?Q#1#C$!`,`!3`
M]/___O4```%HP!```$HTXQ`0```$!_$-$.,0$`P`%,#T___^Y0```8#`$```
M2BCC$!````0'\0T0XQ`0#``4P/3___[5```!F,`0``!*'.,0$```!`?Q#1#C
M$!`,`!3`]/___L4```&PP!```$H0XQ`0```$!_$-$.,0$`P`%,#T___^M0``
M`<C`$```2@3C$!````0'\0T0XQ`0#``4P/3___ZE```!X,`0``!)^.,0$```
M!`?Q#1#C$!`,`!3`]/___I4```'XP!```$GLXQ`0```$!_$-$.,0$`P`%,#T
M___^A0```A#`$```2>#C$!````0'\0T0XQ`0#``4P/3___YU```"*,`0``!)
MU.,0$```!`?Q#1#C$!`,`!3`]/___F4```)`P!```$G(XQ`0```$!_$-$.,0
M$`P`%,#T___^50```EC`$```2;SC$!````0'\0T0XQ`0#``4P/3___Y%```"
M<,`0``!)L.,0$```!`?Q#1#C$!`,`!3`]/___C4```*(P!```$FDXQ`0```$
M!_$-$.,0$`P`%,#T___^)0```J#`$```29CC$!````0'\0T0XQ`0#``4P/3_
M__X5```"N,`0``!)C.,0$```!`?Q#1#C$!`,`!3`]/___@4```+0P!```$F`
MXQ`0```$!_$-$.,0$`P`%,#T___]]0```NC`$```273C$!````0'\0T0XQ`0
M#``4P/3___WE```#`,`0``!):.,0$```!`?Q#1#C$!`,`!3`]/___=4```,8
MP!```$E<XQ`0```$!_$-$.,0$`P`%,#T___]Q0```S#`$```25#C$!````0'
M\0T0XQ`0#``4P/3___VU```#2,`0``!)1.,0$```!`?Q#1#C$!`,`!3`]/__
M_:4```-@P!```$DXXQ`0```$!_$-$.,0$`P`%,#T___]E0```WC`$```22SC
M$!````0'\0T0XQ`0#``4P/3___V%```#D,`0``!)(.,0$```!`?Q#1#C$!`,
M`!3`]/___74```.HP!```$D4XQ`0```$!_$-$.,0$`P`%,#T___]90```\#`
M$```20CC$!````0'\0T0XQ`0#``4P/3___U5```#V,`0``!(_.,0$```!`?Q
M#1#C$!`,`!3`]/___44```/PP!```$CPXQ`0```$!_$-$.,0$`P`%,#T___]
M-0``!`C`$```2.3C$!````0'\0T0XQ`0#``4P/3___TE```$(,`0``!(V.,0
M$```!`?Q#1#C$!`,`!3`]/___14```0XP!```$C,XQ`0```$!_$-$.,0$`P`
M%,#T___]!0``!%#`$```2,#C$!````0'\0T0XQ`0#``4P/3___SU```$:,`0
M``!(M.,0$```!`?Q#1#C$!`,`!3`]/___.4```2`P!```$BHXQ`0```$!_$-
M$.,0$`P`%,#T___\U0``!)C`$```2)SC$!````0'\0T0XQ`0#``4P/3___S%
M```$L,`0``!(D.,0$```!`?Q#1#C$!`,`!3`]/___+4```3(P!```$B$XQ`0
M```$!_$-$.,0$`P`%,#T___\I0``!.#`$```2'CC$!````0'\0T0XQ`0#``4
MP/3___R5```$^,`0``!(;.,0$```!`?Q#1#C$!`,`!3`]/___(4```40P!``
M`$A@XQ`0```$!_$-$.,0$`P`%,#T___\=0``!2CK;_`P`"3C\/](_W'C,/"H
M`"3C0/"@`"10(/"T04#PH$$P\*A!(/"TP.7___Y\Q$@``$AUQ"@``$ANN00`
M-,#E___](<08``!(.I4`$`"G=``>P.7___W7Q"L``$C,["8`"`!\IRD``<#E
M___^C,#E___^Z<08``!(-N,@$```%L#E____8)(`*B?$N```2"OC(+```!;`
MY?___U66`B1ZXR"P```6P.7___]-E@$D>E@@\+3LL@`#`-BG*@`$N10`(NLB
M``,`#<#E___^G.-`\*@`!.,00```!.,0(```),`0```:T^,0(`@`),08``!(
M4N,0(!``),`0```:R>,0(!@`)+D$`%+$*P``2&RG&``!XR#PM``2N?+0(:<Y
M``#L$P`$`-BG.P`!N10`$>L1``,`#;D(`!6G)@!7N10`2^5($````*=I``#`
M,```!$_$*```2%#`Y?___/48LNPF``H`?L0H``!(1L#E___^*QBRQ"@``$@_
MP.7___V4P"```!F`P.4```&:["8`'P!\P!```$@LXQ`0```"IW0`"\`@```9
M1\#E```!B<0K``!('L`0``!(&^,@$````J>$``7`Y0``##/$*```2!3`Y?__
M_NG`Y?__^Z:Y%``KZV_PZ``$!_[KHP`#``WC"D````3C`!```"2G]/^4!P<'
M![D$`"_`,````!+C,#```!BG^_]@IPD``.,`\```),#T````"0<'!P<``(L(
M!P<'!^MO\#``)$%`(`CC\/]8_W'$:```1T#E2/"@``#$6```1T;C,"`$`!3$
M*```1RC`Y?___3'K;_#8``0'_@<'!P?`$```1Y3`(```1Y'L$@`*@&3$&```
M1R?L&``$`'P'\0?^!P<'!P<'P!```$>`P#```$=]N0D`,>L3``,`"NLS`#\`
M#+D(`#'K,P`!``KL.``-`'S$&```1Q[L&``'`'S`(```1V0'\0?^!P<'!P<'
MZY_P2``DP)```$=9X_#_8/]QE0"0`*=T`$O`$```1OOC$!````*GA``(Q"@`
M`$<+P.7___T8P!```$4%P+```$4&P*```$3_N0D`L<08``!'.NN[``,`"J>[
M___L&P`5H&6G&P`!Q!L``$<MZQ$``P`-XQ&@```$#>'$&```1R/L&__Q0&7`
MY?___X7`$```1J[C$!````*GA``(P"```#?*P.7___L_D@&0`.N?\.@`!`?^
M!P<'!^OO\'``)./P_V#_<>OO\1``!`?^!P<'!\`0``!&I.,0$````J>$`!?K
M[_!P`"3`,```1O'C\/]@_W'`(```-Y_`Y?___,3K[_$0``3`]/___UK`]/__
M_U?K[_!P`"3C\/]@_W'K[_$0``0'_@<'!P?K;_`P`"3C\/]@_W'L*`!-`'S$
M&```1F?CH!````*GA`!$N00`8[D$`(*Y!`!"XQ!```"4[!8`+@!^&TBY!`!Z
MN10`E..P<````J>$`!VY!`!)N00`.+D$`"O`Y?__^U_L)@`?`'Y!&;``E3T0
M`*=T`!BYZ:"G0;FP`>NJ``,`"E"@8`"Y!``KZV_PT``$!_[L&/_5/7Y!0$`!
MI_3_RD%P<`BG]/_1I[D``*?T_^T'!^N_\%@`)./P_U#_<;)/`+!!,/"DZ[L`
M(``-LD\`L=('\*BP*,#E____EM4'\*BP**>$``7`Y?___6KKO_$(``0'_@<'
M!P<'!^N?\$@`)./P_U#_<;)/`*#KJ@`@``VR3P"AN00`LM('\*B@*$&0\*2Y
M!``YN00`*\#E____;.PF``L`?-4'\*B@**>$`![`Y?___3WC$/"D`!3$*```
M1<OK$0`#``WC$"````CC(!`(``3C(!```"3L*/_<`'Q!$!`(I_3_]>N?\/@`
M!`?^!P?K;_`P`"3C\/[(_W&R3P"0ZYD`(``-LD\`D=('\3"0*.PH`"<`?+D$
M`**5`"``IX0`(,#E___YH[D$`'+L*``9`'Q!8/"@N00`)\#E___Z1[D$`++L
M)@`5`'RY!``GP.7___K-N00`*L#E___\.-4'\3"0**>$`&[`Y?___.!!L+`3
MP!```!;7IP@``+D$`"NR70`2IQ3__J>$_]?`$```%M^Y!``KLET`$J<4__ZG
MA/_,N00`*J<9``"R7@`2IQ3__KD$`#NY"0`:IRD``+)>`".G%/_^N0D`*QH2
MIQH``KD4`"'`Y?__^CK`,```%KJY!`""N00`6[D$`$K`Y?___&ZY!``VN00`
M*,#E___\)^PH`!G_?E@0\+BG*$``P!L``/``[!(`#V!VN00`*,#E____:;D$
M`"C`Y?___`"G]/^$N00`*,#E___Y^:?T__3K;_%H``0'_NNO\%``)./P_LC_
M<;)/`+"Y!`"BZ[L`(``-03#PH+)/`+'2!_$PL"C`Y?__^BSL)@`I`'X8$J<X
M0`!8(/"XP"L``/``[",`"(!VI3^@`.PC``]@=J<Y``*Y!``JP.7___DB$!*G
M&O__B!``']4'\3"P*+D4`"&GA``)P.7___PSIQ@``*?T__3KK_&(``0'_NMO
M\#``)./P_U#_<;)/`(#KB``@``VR3P"!N00`HM('\*B`*+D$`+.5/3``IW0`
M!$&P,`&G"```N00`&Z>9``!!,/"DLEX`D:<4__ZY!``JN0D`F\#E___^(NPH
M`"8`?*<(``"G&0``N00`,K)>`!.G%/_^N0D`$NR1`%\@9:<9``#C,;```)!"
M,2``IQL``>PV__D`?-4'\*B`**>$`,?`Y?__^]C$&```1&GCT!````2G&0``
M&'&G&P`!ZR$``P`-XR+?^/\"IW3_]^PG``(`V,`0``!$R[D4`"+C$!```!+K
M(@`#``VGA`!]N00`,KD$`"W`Y?__^&[$&```1#_C(!```"3L*/_(`'SL%P`!
M`-C$*```1#.Y%``1XR`@```$ZQ$``P`-01$@`.5($````%!P\*2Y!``:XR`0
M``"4["@`!@!^["8`;CU^N0D`&NPI``(`V;D8`"'$>```1`_C8/"D`!3K9@`#
M``WC8'````C`Y?__^/_C(&```"3L*/^,`'SC$/"D`!3C('````3K$0`#``WC
M$2````3C(*```)!"(!``0:"@`;D$`#'`*P```/]!$!`!IX0`!>PF__`]?I(]
M,`"G*0``XS*P``"00C(0`*<K``'L-O_Y`'RG]/]<P!```$1#Y4P0```!P.7_
M__C!N00`8NPH_T\`?+D4`$>Y!``]ZT0``P`-P.7___C"Q!@``$.SXV`0```D
MI_3_=T$0$`&G]/^*ZV_PX``$!_X'!P<'!P?K[_!P`"3$&```0YGC\/]@_W'C
M(!```!;`Y?__^L#`4```-"3$2```0Y[`,```%0WK[_$0``3`]/__^I$'!P<'
MZV_P,``DX_#_6/]QQ+@``$-VXR"P```6P&```!9"P.7___J=P.7____.XR"P
M```6P.7___J4N00`5N5(\*```,!````&O,`P```4[<#E___WQNMO\-@`!`?^
M!P<'!P<'ZV_P,``DX_#_4/UQXQ#PJ`)QLD\`@.N(`"``#;)/`('2!Q``@"C`
MY?__]^E!L/"FN00`4L!@```4T<!````4T*<Y$`&Y!``KP.7___>(["8`$/]^
MI[D``.,0\*@"<=4'$`"`**>$`$K`Y?__^HCL(!``(''L)/_P`'[CH/"G`7&G
M21``N00`.KD$`"O`Y?__^0:Y!`"2["3_WP!^IRH``;D4`"+`Y?__]_JY!`"R
M["C_TP!\N10`>>PJ``>@9;GH<!*Y84"A[+H`!\!EN>AP&KEA0+'LD!`!('*Y
M!`!'N00`.KD$`"O`Y?__^BE!%[``D@`0`*?T_[*Y!``KZV_PX`($!_X'!P<'
MP/3___]\!P?K;_`P`"3C\/[`_G'C$/$X`7&Y!`"RN00`<[)/`(#`(```%%SK
MB``@``VR3P"!T@<0`(`HP.7___R6ISD`+[D$`)*Y!``KP.7___A1["@`%@!\
MN00`.\`@```41<#E___]WN,0\3@!<=4'$`"`**>$`*[`Y?__^?NG"```N00`
M&[D$`">GJ0``P#```!0SLEX`H:<4__[`Y?__^9D;J[D$`%*GJ@`!07#Q.$'0
M\*CL6/_2`'R5`%``P!```!/4N>*`4>R8`!L`?*<(``"Y!``5N00`*;)=`!*G
M%/_^IW0`#L`P```4!Z<I``#`Y?__^6^Y!`!2I_3_W:<(``"G&0``N00`);)>
M`!*G%/_^&Q7L,?__`-BY!``EN1@`(Y4O(`"GA``A&AJG*`__[!+_E"!VX[#P
MH``DP&```!/=P$```!1'ISD0`+D$`"?`Y?__]G^G&!``IRH``>PA``K`=Z?T
M``&2`"``&!.G]/_3N00`/;D$`"?`Y?__^0KL)O^S`'Y8$/#`I2^``,`;``#P
M`.P2_ZE@=J<Y``&Y!``GP.7___9&[";_GP!^N00`-\`@```3FL#E___],[D$
M`"?`Y?__]T:Y!`"RI_3_3KD$`"OK;_%P`00'_@<'N00`$N,P$```E.PV``0`
M?@?^01`0`:<^`"^YXH`AI_3_\P<'!P<'!^PH``D`?+D$`#*5`"``IW0`",`@
M```3)\#T___W&*<(``"G&0``LEX`$J<4__[C0!___W&YZ3`A[#0`!B!E[#8`
M!?]\IRD``:<G`!/L-``J8&25+S``IX3_WL`@```32Z?T_]SC0$___W&G]/_O
ME2]``*>$__FYZ3`4IQL``;DA`#2G*0`!N>(P$J<7``2G]/_?XR!/__]QE2]`
M`*=T`#:YZ3`4XR!/__]Q[#(`!B!E[#8`!?]\IQD``>-`3___<:<7`"BY"0!#
MIRD0`.P4``(`V>P2`"4@9>OO\'``)*=+``'C\/]@_W'L0!``(''`(```0=G`
MY?__]UK`(```0=/K[_$0``0'_KD$`$*G]/^_E2]``*>$_].G]/_6IRD```?^
M!P<'!P<'Z[_P6``DP!```#'$X_#_,/]QLD\`L.N[`"``#;)/`+'2!_#(L"C2
M(?"F$`K`(```$L_`Y?__^R?`(```$L[`Y?__^R'`(```$LS`Y?__^QO`(```
M$LO`Y?__^Q7`(```$LG`Y?__^P_`(```$LO`Y?__^PG`(```$IW`Y?__^P/`
M(```$L7`Y?__^OW`(```$L3`Y?__^O?`(```$L/`Y?__^O'`(```$HK`Y?__
M^NO`(```$KS`Y?__^L'L*``+`'RY!``RP"```!*GP.7___P2P"```!*TP.7_
M__JPN00`,NPH``D`?,`@```2*<#E___\`<`@```2K,#E___ZG[D$`#+L*``:
M`'S`(```$E+`Y?__^_#`,```$K+`(```$FG`Y?__^^?5!_#(L"BGA``FP.7_
M__@'P"```!*2P.7___I]N00`,NPH``@`?,`@```27J?T_]ZG20`*P#```!*)
M02#PM\#E___UG>PF_]4`?D$P\,&G]/_LZ[_Q*``$!_X'!P<'!P?$'0``0)"G
M'O__IW0`+NOO\'``),`@```2-^/P_V#_<<#E___Z2.PH`!P`?.,0(```D)4`
M(`"GA``4P!<````PN0,`$>P1/[\!5<0?``!`:^OO\1``!,0L``!`90?^IQ@`
M`*?T__3$+```0%T'_@<'Z^_P<``DX_#_8/]QP.7___>NP.7___7[["@`!@!\
MXR`@```$Z^_Q$``$!_X'!P<'ZV_P,``DN00`LN/P_V#_<<`@```2(L#E___Y
M_;D$`#OL*``)`'RY!`!BE0`@`*=T``O`(```$A'K;_#0``3`]/__^T7`Y?__
M]7KL)@`M`'RG"```N00`&[)>`"&G%/_^N00`-J<9``"R7@`3IQ3__KD)`!:Y
M"0`K02(0`L#E___TWL`P```1_+D$`*+`4```$8FY!`!+P.7___<1N00`.J?T
M_\GK;_#0``0'_@<'!P?K;_`P`"3C\/X8]W'C$/'@"'&R3P!PZW<`(``-LD\`
M<=('$`!P*,`0```_U;D$`(+`(```$5/2#_"P$`C2!_#`$!C2+_#@$"#2#_#(
M$%#2!_#8$&#`Y?__^8;L*``?`'RY!`"RE0`@`*>$`!C`Y?___W+C$/'@"''5
M!Q``<"BGA``%P.7___;SN00`*^MO\A@(!,#T___TV\#E____1+D$`++L)@`E
M`'Q!H/#(XR"@```"IW0`!\"P```1?Z?T`!C`Y?__^5#L)@`'`'RGJP`(I_3_
M[I4`(`"GA/_ZP.7___2VN00`LNPH__,`?*<(``"Y!``;IRD``+)>`"&G%/_^
MN0D`*^LB``$`#:<K``'`Y?__]#VY!`!BN00`HN-`L```E.Q&`)L`?D&@\.#C
ML*````*GA``=N00`*\#E___Y$[D$`++L*`":`'R5`"``IX0`E<#E___Z&^PH
M`)``?KD$`"O`Y?__]'.Y!`"R0:#PL.RV``P`?..0H````J>$``:5`)``IW0`
M?J<(``"Y!``;IYD``+)>`)&G%/_^N00`)J<9``"R7@`2IQ3__KD)`!:Y"0";
M&I&GF@0$N10`F;D$`"G`Y?__\^/C8/"@`"2Y!`"BP#```!#[P&```!#UP%``
M`!")N00`2\#E___V$*<Y`<"Y!``JP.7___6I["8`5?]^P.7___636&`@`.QH
M`$T1?L08```^H[D4`&:Y!`!:XT"````$P#```!#6XR`0```$P.7___4+I[D`
M`.,0\>`(<=4'$`!P**=T_QVY!``KZV_R&`@$!_ZY!``JN10`1,`P```0KL#E
M___UT4&PL`%!H*`"I_3_5*>K``BG]/]8N00`*<#E___Y@NPH``H`?KD$`"G`
MY?__\]JY!`"RIZL`"*?T_V=!,/$0N00`*L#E___SK1C2["@`%@!^Q!@``#Y.
MN00`6N-`@```!,`P```0H>,@$```!,#E___TN*?T_ZU8$/$HIRA``,`;``#P
M`.P2_^9@=EBP\2S`Y?__]<?LLO_>8'98$/$HIR@!P,`;```!_^P2_]1@=KD$
M`"G`Y?__\S6Y!`"RP"```!"=P.7___@9["8`Q@!\XY"````$IP@``*<9``"Y
M!``ILEX`$J<4__ZY"0`9[!P`/@-^N10`(>,RG_S_<<`@```0@+)=`".G%/_^
MIW0`+^P8``T$?J<:__NY%``101&0`)4O$`"G=``BXQ"`"``"IX0`':<(``"G
M*0``N00`,;)>`".G%/_^N0D`(>PL``\#?>,R'_S_<<`@```05K)=`".G%/_^
MN>*`D<#E___];NPF`-\`?KD$`"FG.0``P.7___-`N00`DAB"["@`T@!^ITD`
M`J<Y_^Y!8/'@P.7___)AITD`!KD$`#:Y!``IP.7___18E0#QX*=T`&.50_'A
MIW0`7Y5!\>*G=`!;E4/QXZ=T`%>52/'DIW0`4Y5%\>6G=`!/ITD``J<Y_\:Y
M!``IP.7___(WITD`*;D$`#:Y!``IP.7___0NP!```!!=XQ#PH``DP%````\Y
MN00`2L`P```/]KD$`"O`Y?__]+NY!``JP.7___1FN00`.\`@```/&,#E___X
MMKD$`"O`Y?___4VG]/[`XY"````$P.7___+!N00`,KD$`"G`Y?__^I:Y!`"2
M[";_,0!\I_3_*Z=)``"G.0``N00`*<#E___QZL#E```-![D4`(BY!`#2I4^`
M`+D$`#:Y!``HP.7___/:["(`-`!^N00`*$&0\:-!@/&WP.7___.NN00`/;D$
M`"FY!`#8P.4```W%IVD`%.-`D```D+D$`"C`,```#S7`Y?__]%BGFP`!IXL`
M`J=G__'`$```#^&2`/'?XQ#PH``DN00`;:?T_X"Y%`!"N00`-KD$`"W`Y0``
M#/6G]/^ZP#````\%P"````[*P.7___@ZP.7___&?P!````^^N00`8N,0\*``
M),!0```.F+D$`$K`,```#UVY!``KP.7___0:ISD!P+D$`"O`Y?__\[/L)O]8
M_W[`Y?__\YU8$"``IQX`$:=T_T[`Y?__\73`$```#Y/C$/"H`"2GV@`!N10`
M';D$`&+C$/"@`"3`4```#F:Y!`!*P#````\RN00`*\#E___SZ*?T_\X'!P<'
M!P?KG_!(`"3C\/]@_W'$J```/)KC(*```!;`Y?__\\2Y!`"RXR"@```6P.7_
M__.\T@`@L;"PP"````Y-P.7___9O["@`"P!\E3$@`*=T``:5`"`!IX0`!<#E
M___[1<2H```\<N,@H```%L#E___SG*=9``.G20`!P#````[SP.7___("N00`
MLNPH`"X`?.,@H```%L#E___SA^,0L!``!,!````.X.,P$```!,#E___R"^,0
ML!``!.,0$```!)%`$`VGA``1XR"@```6P.7___-KXQ"P$``$XS`0```$P.7_
M__$2Q)@``#POXR"0```6P.7___-9IUD``Z=)``'`,```#K3`Y?__\;^Y!`"R
M["@`/P!\P"````W#P.7___8`N00`HNPH`!8`?.,@D```%L#E___S.>,0L!``
M!+D$`$KC,!````3`Y?__\;ZG]``@P.7___BMN00`HN,@D```%NRH`%\`?,#E
M___S'N,0L!``!+D$`$KC,!````3`Y?__\:.Y!``JP.7___+.Q+@``#O;XR"P
M```6P.7___,%N00`HN,@L```%L#E___R_:=)``'`,```#EO`Y?__\`7`0```
M#F"Y!``RN00`*L#E___Q>^,@L```%L#E___RY9(`(+'`(```#5?`Y?__]9G$
M*P``/"[L)@`C`'S$*```/"3`Y?__^]W$*P``/"+L)@`7`'S`(```#CG`Y?__
M\!7`Y?__\L+$.```/`_C$+`0``3C0#````2G]/^%ISD!P,0H```\!L#E___R
M7[D$`%+L*``8$7[L$@`!`-CL'``2`7_$&```._'$2```._+C,!````3`(```
M#AK`Y?__[^7KG_#H``0'_@<'!P?KK_!0`"3C\/]@_W&Y!`"RP.7___F0P.7_
M__EYN00`HL#E___ZX.PH`!T`?NRX`!H`?)4`L`"GA``5P#````U<N00`*L#E
M___PNNRB``M@9+D$`"OKK_#P``3`]/__]8/KK_#P``0'_K)/`!#K$0`@``VR
M3P`1ZV_P,``DIUD`"./P_-#_<=('\R@0**>Y``!!$/"HN00`,>-+(#@`!.L$
M`"``#.,`,```),!*`````.-`,`@`)*>[``BG.P`0IU?_[:=)`$#C,!!H``3C
M,!!``(+C,!`0`(+C,!```(+L4R"_(57L4R`^`5;C4!"``"2G&P`(IT?_Z>.@
M\*@`!,*J6H)YF>.@("``".,P(```!.-`(!``!.,`(`@`!.,0(!@`!.,0\*``
M).RS(+\E5;GG$!3LLR`Z!5:Y@``0N0@`NN,0\*``@NN0``(`#+D(`+'LD``A
M'E;LV2"_`%6YY]"DN8``H[F"`*3L>R"_`%7C@/"P``3"BEJ">9GC@/"@``BY
M"`"*[*L[OR55Z[,``@`,[*<`.@56[+,`(1Y6N0@`J+F"`)NY@`"7N>?0&>R*
M(+\`5>QK(+\`5>.0\+@`!.-0\,``!,*:6H)YF<):6H)YF;D(`)2Y"`"1[!H[
MOR55ZZ<``@`,[*<`(1Y6N8(`NKF``+BY@@"V['H@OP!5[!@`.@56N0@`U;D(
M`!FY"`#;[)$@OP!5Z[@``@`,XU#PR``$[+@`(1Y6PEI:@GF9N8(`J[D(`&6Y
M@`"IN8(`I[D(`*;LBR"_`%7L$3N_)57C4/#0``3L&0`Z!5;"6EJ">9FY"``=
M[-$@OP!5[!$[OR55[!T`.@56N0@`&NNI``(`#.RI`"$>5KF"`+JY@`"]N8(`
MN.QA(+\`5>R:(+\`5;D(`'7C4/#8``2Y"`![PEI:@GF9Z[T``@`,[+T`(1Y6
MN8(`J[F``*:Y@@"I[-L@OP!5N0@`A>P1.[\E5;D(`(KL%@`Z!5;KI@`"``RY
M"``7[*8`(1Y6['$@OP!5N8(`NN-0\.``!+F``+?"6EJ">9FY@@"][&H@OP!5
MN0@`E>P1.[\E5;D(`)OL%P`Z!5;KMP`"``RY"``8[+<`(1Y6[($@OP!5N8(`
MJ^-0\.@`!+F``*C"6EJ">9FY@@"F['L@OP!5N0@`U>P1.[\E5;D(`-KL&``Z
M!5;KJ``"``RY"``9[*@`(1Y6[)$@OP!5N8(`NN-0\/``!+F``+G"6EJ">9FY
M@@"W[(H@OP!5N0@`9>P1.[\E5;D(`&OL&0`Z!5;KN0`"``RY"``=[+D`(1Y6
M[-$@OP!5N8(`J^-0\/@`!+F``*W"6EJ">9FY@@"H[)L@OP!5N0@`=>P1.[\E
M5;D(`'KL'0`Z!5;KK0`"``RY"``6[*T`(1Y6[&$@OP!5N8(`NN-0\0``!+F`
M`+;"6EJ">9FY@@"Y[-H@OP!5N0@`A>P1.[\E5;D(`(OL%@`Z!5;KM@`"``RY
M"``7[+8`(1Y6['$@OP!5N8(`J^-0\0@`!+F``*?"6EJ">9FY@@"M[&L@OP!5
MN0@`E>P1.[\E5;D(`)KL%P`Z!5;KIP`"``RY"``8[*<`(1Y6[($@OP!5N8(`
MNN-0\1``!+F``+C"6EJ">9FY@@"V['H@OP!5N0@`U>P1.[\E5;D(`-OL&``Z
M!5;KN``"``RY"``9[+@`(1Y6[)$@OP!5N8(`J^-0\1@`!+F``*G"6EJ">9FY
M@@"G[(L@OP!5N0@`9>P1.[\E5;D(`&KL&0`Z!5;KJ0`"``RY"``=[*D`(1Y6
M[-$@OP!5N8(`NN-0\2``!+F``+W"6EJ">9FY@@"X[)H@OP!5N0@`=>P1.[\E
M5;D(`'OL'0`Z!5;KO0`"``RY"``6[+T`(1Y6[&$@OP!5N8(`J^-0\2@`!+F`
M`*;"6EJ">9FY@@"I[-L@OP!5N0@`A>P1.[\E5;D(`(KL%@`Z!5;KI@`"``RY
M"``7[*8`(1Y6['$@OP!5N8(`NN-0\3``!+F``+?"6EJ">9FY@@"][&H@OP!5
MN0@`E>P1.[\E5;D(`)OL%P`Z!5;KMP`"``RY"``8[+<`(1Y6[($@OP!5N8(`
MJ^P1.[\E5;F``*CL&``Z!5:Y@@"FN0@`&>-0\3@`!,):6H)YF;D(`-6Y"`"M
M[)$@OP!5['L@OP!5[-$[OR55[-$@.@56XQ#Q0``$N0@`VL(:6H)YF>NH``(`
M#+D(`&'LJ``A'E:Y@@"ZN8``N;F"`+>Y"`"VXQ#Q2``$[&T[OR55PAINV>NA
M[&T@.@56N0@`%[D(`&OKN0`"``SLN0`A'E:YY[":N8(`G;D:`!GL=CN_)57L
MG2*_/E7L=B`Z!5;LG0(A'E:Y"`!QN>>0B^,0\5``!+F"`(;"&F[9ZZ&Y&@`:
MN1H`&.R&(K\^5;D$`*'LA@(A'E;L%SN_)57L%R`Z!5:Y"``:XZ#Q6``$PJIN
MV>NAN>>`:;D:`*NY@@!GN00`NKD:`+;LH3N_)57L9R*_/E7LH2`Z!5;L9P(A
M'E:Y"`"KN>=@>..P\6``!+F"`''"NF[9ZZ&Y&@"YN1H`M[D$`)OLNCN_)57L
MNB`Z!5:Y"`"Y[)$BOSY5[)$"(1Y6XQ#Q:``$N>>0=L(:;MGKH;F"`'JY&@`8
MN1H`%[D$`('L&SN_)57L&R`Z!5:Y"``8[(HBOSY5[(H"(1Y6XZ#Q<``$PJIN
MV>NAN1H`IKGG@&FY@@!KN1H`IKD$`'KLH3N_)57LH2`Z!5:Y"`"G['LBOSY5
M['L"(1Y6X[#Q>``$N>=P:,*Z;MGKH;F"`&&Y&@"YN1H`MKD$`)OLNCN_)57L
MNB`Z!5:Y"`"Y[)$BOSY5[)$"(1Y6XQ#Q@``$N>>09\(:;MGKH;F"`&JY&@`8
MN1H`%KD$`('L&SN_)57L&R`Z!5:Y"``8[(HBOSY5[(H"(1Y6XZ#QB``$N>>`
M:<*J;MGKH;F"`&NY&@"GN1H`IKD$`'KLH3N_)57LH2`Z!5:Y"`"G['LBOSY5
M['L"(1Y6X[#QD``$N>=P:,*Z;MGKH;F"`&&Y&@"YN1H`MKD$`)OLNCN_)57L
MNB`Z!5:Y"`"Y[)$BOSY5[)$"(1Y6XQ#QF``$N>>09\(:;MGKH;F"`&JY&@`8
MN1H`%KD$`('L&SN_)57L&R`Z!5:Y"``8[(HBOSY5[(H"(1Y6XZ#QH``$N>>`
M:<*J;MGKH;F"`&NY&@"GN1H`IKD$`'KLH3N_)57LH2`Z!5:Y"`"G['LBOSY5
M['L"(1Y6X[#QJ``$N>=P:,*Z;MGKH;F"`&&Y&@"YN1H`MKD$`)OLNCN_)57L
MNB`Z!5:Y"`"Y[)$BOSY5[)$"(1Y6XQ#QL``$N>>09\(:;MGKH;F"`&JY&@`8
MN1H`%KD$`('L&SN_)57L&R`Z!5:Y"``8[(HBOSY5[(H"(1Y6XZ#QN``$N>>`
M:<*J;MGKH;F"`&NY&@"GN1H`IKD$`'KLH3N_)57LH2`Z!5:Y"`"G['LBOSY5
M['L"(1Y6X[#QP``$N>=P:,*Z;MGKH;F"`&&Y&@"YN1H`MKD$`)OLNCN_)57L
MNB`Z!5:Y"`"Y[)$BOSY5[)$"(1Y6XQ#QR``$N>>09\(:;MGKH;F"`&JY&@`8
MN1H`%KD$`('L:B*_/E7L&SN_)57L:@(A'E;L&R`Z!5;CH/'0``2Y"``8PJIN
MV>NAN1H`I[GG8'FY@@![N1H`I[D$`(KCT/'8``3LH3N_)57"VF[9ZZ'LH2`Z
M!5:Y&@#9N0@`J.R+(K\^5>R+`B$>5KD$`+VYYX"6N8(`D;D:`+GL>B"_`%7L
MVCN_)57LUP`Z!5:Y"`#;[+$BOSY5[+$"(1Y6XQ#QX``$PAINV>NAN1H`%K/!
M``&YY[`8N8(`&K/-`*#LG2"_`%7LW3N_)57LV0`Z!5:Y&@"AZQ<``@`,N0@`
MK>P7`"$>5NQQ(+\`5;GF$-NYY'!;N8``V;F!`-7L:B"_`%7C4/'H``3"6H\;
MO-RY&@!8N>A0C>S:.[\E5>NI``(`#.RI`"$>5KF!`!JY@``6N>1PFKF!`)'C
M$/'P``3"&H\;O-RY&@`;N0@`&>S6`#H%5KD(`-CLC2"_`%7LO3N_)57LN``Z
M!5:Y"`"QZQ8``@`,[!8`(1Y6[&$@OP!5N>1@6KGF$-JY@`#8N8$`U>-0\?@`
M!,):CQN\W+D(`'7LFR"_`%6Y"`#7['L[OR55Z[@``@`,[+@`(1Y6N8$`&[F`
M`!FYY&"+N8$`@>,0\@``!,(:CQN\W+D:`!JY"``8['D`.@56N0@`?>S7(+\`
M5>RG.[\E5>RM`#H%5KD(`*'K&0`"``SL&0`A'E;LD2"_`%6YY)!;N>80>[F`
M`'VY@0!UXU#R"``$PEJ/&[S<N0@`9>R*(+\`5;D(`';L:CN_)57KK0`"``SL
M:``Z!5;LK0`A'E:Y"`!GN8$`&KF``!CL=B"_`%6YY)#:N8$`T>,0\A``!,(:
MCQN\W+D:`!OLMCN_)56Y"``=[+<`.@56N0@`L>QK(+\`5>L8``(`#.P8`"$>
M5NR!(+\`5;GD@%JYYA#:N8``U[F!`-7C4/(8``3"6H\;O-RY"`"5N0@`V>R;
M.[\E5>NW``(`#.RW`"$>5KF!`!NY@``6N>2`>[F!`''C$/(@``3"&H\;O-RY
M&@`:N0@`%^R6`#H%5KD(`)WLV2"_`%7LJ3N_)57LK0`Z!5:Y"`"AZQ8``@`,
M[!8`(1Y6['$@OP!5N>1P6[GF$&NY@`!MN8$`9>-0\B@`!,):CQN\W+D(`(7L
MFB"_`%6Y"`!H[(H[OR55ZZT``@`,[*T`(1Y6N8$`&KF``!FYY'#:N8$`T>,0
M\C``!,(:CQN\W+D:`!NY"``=[(D`.@56N0@`ANQH(+\`5>RX.[\E5>RV`#H%
M5KD(`+'K&0`"``SL&0`A'E;LD2"_`%6YY)!:N>80VKF``-:Y@0#5XU#R.``$
MPEJ/&[S<N0@`=>R+(+\`5;D(`-?L>SN_)57KM@`"``SLM@`A'E:Y@0`;N8``
M&+GDD&NY@0!AXQ#R0``$PAJ/&[S<N1H`&KD(`!;L>``Z!5:Y"`!][-<@OP!5
M[*<[OR55[*T`.@56N0@`H>L8``(`#.P8`"$>5NR!(+\`5;GD@%NYYA!KN8``
M;;F!`&7C4/)(``3"6H\;O-RY"`"5['H@OP!5N0@`:>R:.[\E5>NM``(`#.RM
M`"$>5KF!`!JY@``7N>2`VKF!`-'C$/)0``3"&H\;O-RY&@`;N0@`'>R7`#H%
M5KD(`);L:2"_`%7LN3N_)57LM@`Z!5:Y"`"QZQ<``@`,[!<`(1Y6['$@OP!5
MN>80VKGD<%JY@`#6N8$`U>-0\E@`!,):CQN\W+D(`(6Y"`"-Z]8``@`,[-8`
M(1Y6N>;08;GD<!WLFR"_`%7LNSN_)56Y@`!I[+D`.@56N8$`8;D(`+CC$/)@
M``3"&H\;O-RY&@`:N0@`8>R+(+\`5>P;.[\E5>NY``(`#.P8`#H%5NRY`"$>
M5KD(`!;LFR"_`%6YYK!MN>207;F``&BY@0!EXU#R:``$PEJ/&[S<N0@`=;D(
M`';K:``"``SL:``A'E:YYF"+N>20MNRA(+\`5>P1.[\E5;F``(KL&@`Z!5:Y
M@0"+N0@`%^.P\G``!,*ZCQN\W+D:`+WL<2"_`%6Y"`"+[+$[OR55ZQH``@`,
M[!H`(1Y6[*$@OP!5N>2@5KGF$-;LMP`Z!5:Y@`#7N0@`N+F!`-7C4/)X``3"
M6H\;O-RY"`"5N0@`V>R+(+\`5>R;.[\E5>R;(#H%5KD(`)WKUP`"``SLUP`A
M'E:YY*"]N8$`';F``!BY@0`;X[#R@``$PKJ/&[S<N1H`MKD(`+'K>``"``SL
M&3N_)57L>``A'E;L&2`Z!5:YYW"-N0@`&[F"`(GCL/*(``3"NLIBP=:Y"`"Z
MN1H`N.RA.[\E5>R)(K\^5>RA(#H%5NR)`B$>5KD(`*NYYX!GX[#RD``$N8(`
M8<*ZRF+!UKD:`+VY&@"VN00`F^QA(K\^5>RZ.[\E5>QA`B$>5NRZ(#H%5KD(
M`+GCD/*8``3"FLIBP=:Y&@"7N>=@>+D$`!FY@@!ZN1H`%^R;.[\E5>QZ(K\^
M5>R;(#H%5NQZ`B$>5KD(`)'C$/*@``3"&LIBP=:Y&@`8N>=PAKF"`(NY&@`8
MN00`H>R+(K\^5>P9.[\E5>R+`B$>5NP9(#H%5N.P\J@`!+D(`!K"NLIBP=:Y
M&@"VN>>`9[F"`&FY&@"VN00`J^QI(K\^5>RQ.[\E5>QI`B$>5NRQ(#H%5KD(
M`+KCH/*P``3"JLIBP=:Y&@"GN>=@>+F"`'&Y&@"GN00`FNRK.[\E5>RK(#H%
M5KD(`*GLD2*_/E7LD0(A'E;C$/*X``2YYY!VPAK*8L'6N8(`>[D:`!BY&@`7
MN00`@>P:.[\E5>P:(#H%5KD(`!CLBR*_/E7LBP(A'E;CL/+```3"NLIBP=:Y
M&@"VN>>`:;F"`&JY&@"VN00`>^RQ.[\E5>RQ(#H%5KD(`+?L>B*_/E7L>@(A
M'E;CH/+(``3"JLIBP=:Y&@"IN>=P:+F"`&&Y&@"FN00`FNRK.[\E5>RK(#H%
M5KD(`*GLD2*_/E7LD0(A'E;C$/+0``2YYY!GPAK*8L'6N8(`:[D:`!BY&@`6
MN00`@>P:.[\E5>P:(#H%5KD(`!CLBR*_/E7LBP(A'E;CL/+8``2YYX!IPKK*
M8L'6N8(`:KD:`+>Y&@"VN00`>^RQ.[\E5>RQ(#H%5KD(`+?L>B*_/E7L>@(A
M'E;CH/+@``2YYW!HPJK*8L'6N8(`8;D:`*FY&@"FN00`FNRK.[\E5>RK(#H%
M5KD(`*GLD2*_/E7LD0(A'E;C$/+H``2YYY!GPAK*8L'6N8(`:[D:`!BY&@`6
MN00`@>P:.[\E5>P:(#H%5KD(`!CLBR*_/E7LBP(A'E;CL/+P``2YYX!IPKK*
M8L'6N8(`:KD:`+>Y&@"VN00`>^RQ.[\E5>RQ(#H%5KD(`+?L>B*_/E7L>@(A
M'E;CH/+X``2YYW!HPJK*8L'6N8(`8;D:`*FY&@"FN00`FNRK.[\E5>RK(#H%
M5KD(`*GLD2*_/E7LD0(A'E;C$/,```2YYY!GPAK*8L'6N8(`:[D:`!BY&@`6
MN00`@>P:.[\E5>P:(#H%5KD(`!CLBR*_/E7LBP(A'E;CL/,(``2YYX!IPKK*
M8L'6N8(`:KD:`+>Y&@"VN00`>^RQ.[\E5>RQ(#H%5KD(`+?L>B*_/E7L>@(A
M'E;CH/,0``3"JLIBP=:Y&@"IN>=PF+F"`)&Y&@"I[)L[OR55[)L@.@56N0@`
MFNRA(K\^5>RA`B$>5N,0\Q@`!+GGH-?"&LIBP=:Y@@#;N1H`&+D:`!VY!`"!
M[&D@OP!5[!D[OR55[!8`.@56N0@`&.R+(K\^5>R+`B$>5N.P\R``!,*ZRF+!
MUNS1(+\`5;D(`#OL$3N_)56YYX"Z[!T`.@56N1H`-[F"`)NY&@`YN0@`$\`:
M`````.,0(```)..@("``"+D(`-#C@/"@``C`V@````#CT"`(`"3`B@````#C
M@"`8`"3`J@````#CH"`@`"3K%@`"``SL%@`A'E:Y"`!!P$H`````XT`@$``D
MLD\`$.L1`"``#;)/`!'5!_,H$"BGA``%P.7__^>WZV_S8``$!_[K[_!P`"2G
M*0"`X_#_8/]QP.7__^4XP#%G12,!XS`@```DP#_OS:N)XS`@"``DP#^8NMS^
MXS`@$``DP#$0,E1VY4@@*```XS`@&``DY4@@,```P#_#TN'PY4P@>```XS`@
M(``DZ^_Q$``$!_X'!P<'ZV_P,``DZQ0``P`-N00`HKD$`+3C("`H``2Y"``2
M[$$@OP!5X_#_8/]QN3$`(:?$``7K`:`P`'KC0*`H`"3K&P`=``SC$*`P``CC
M$*`P`"1!D*`XXQ"@>``2IX0`,:>(`$`;@1F+N00`*;GRL(NY&``AN10`2.PC
M``>@9;GH0!*Y84`QN>A`<^PC``7`9;EA0"?`Y?__YP\8&%H0H'A0$*!X[!8`
M,D!^N00`*ANXN10`N\#E___TA[D$`#?KBP`&`-ZGB@`!$KNG&``!N?)0@4%@
MH'BGA@`?[#D`!\!EN>BP&;EA0#'L.0`'H&6YZ+`3N6%`D;D$`$NY!``IP.7_
M_^;:4+"@>.MO\-``!`?^I_0``>PY``;`9>PV__M`94%P,$#LDP`&P&7LE__S
M0&72/Y``,`"Y!``JI[K_P+D4`+O`Y?__]$"Y!``WI_3_Q0<'ZX_P0``DN00`
MHN.0,"@`!..`,#``!.PI.K\]5>P2``$`V+D4`")!(C`XDH`@`./P_V#_<;D4
M`"&Y!`"S04(P..P<`%DX?J<H`$"G60``N?D0$KD$`"2Y%@`QITD``*@D``"G
M%/_^N00`*\#E___T`]<WL#BP.$*`L'-"D+!WZQ@`&``,0A"P<.L8`!``#$(0
ML''K&``(``Q"$+!RZQD`&``,0A"P=.L9`!``#$(0L'7K&0`(``Q"$+!VN00`
M*\#E___SV=(#H`"P!+D$`"O2`Z`$L`S2`Z`(L!32`Z`,L!S2`Z`0L"3KC_#@
M``3`]/__Y=JG*``XIUD``+GY$!*Y!``DN18`,:=)``"H)```IQ3__J?T_[('
M!\08```L[.P8`!K_?.N_\%@`)./P_V#_<<"P```LX`WAX["_^/]QXQ"P```$
M[!;_^?]\Z[_P^``$!_X'_@<'!P?K[_!P`"3C\/]@_W'K[_$0``0'_@<'!P?K
M[_!P`"2Y!``/I_O_8.,`\```),#E___GGNOO\1``!`?^+W1M<```+@!005)?
M5$U01$E2``!414U01$E2`%1-4`!54T52``!54T523D%-10``+BX``"5S+R5S
M`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ
M0D]/5```97AE`"]P<F]C+R5I+R5S`%!!4E]414U0``!005)?4%)/1TY!344`
M`#H`+P!015),-4Q)0@``4$523$Q)0@!015),-4]05```4$523$E/``!005)?
M24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)51P!0
M05)?0T%#2$4`4$%27T=,3T)!3%]$14)51P``4$%27T=,3T)!3%]435!$25(`
M4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X``%!!4E]#3$5!3CT`
M`#$`3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>```<&%R+0``)7,E<R5S
M)7,``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@
M;W!E<F%T:6]N*0H``%!!5$@``'!A<FP``"YP87(``"5S)7-C86-H92TE<R5S
M```E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,``!@`<&5R;```,`!0
M05(Z.E!A8VME<CHZ5D524TE/3@``,2XP-3(`56YA8FQE('1O(&-R96%T92!C
M86-H92!D:7)E8W1O<GD``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"UE```M+0``
M979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF
M(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?
M<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)'!A<E]T96UP+"`D<')O9VYA;64L
M($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?
M0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO
M=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD
M9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T
M96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>
M3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I4
M14U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]
M/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@
M)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR
M;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T
M:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M
M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL
M96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F
M(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P
M<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]
M"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9)
M;G1E<FYA;',Z.E!!4CHZ0D]/5#L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN
M(CL*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D
M7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL
M"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z
M("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM
M>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%2
M3E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92!O
M<B!L87-T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@
M)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1M86=I8U]P;W,["FEF("@D
M<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD;6%G:6-?<&]S(#T@,#L*?2!E;'-I
M9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU;FM?<VEZ92D@/B`P*2!["B1M86=I
M8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L<V4@>PHD;6%G:6-?<&]S(#T@)'-I
M>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL92`H)&UA9VEC7W!O<R`^/2`P*2![
M"G-E96L@7T9(+"`D;6%G:6-?<&]S+"`P.PIR96%D(%]&2"P@)&)U9BP@)&-H
M=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R
M:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K
M/2`D:3L*;&%S=#L*?0HD;6%G:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA
M<W0@:68@)&UA9VEC7W!O<R`\(#`["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M-"P@,#L*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@-"`M('5N<&%C:R@B3B(L("1B=68I+"`P.PHD9&%T85]P;W,@/2!T96QL
M(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,
M12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T
M.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL
M;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M
M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=
M>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@
M/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@
M)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII
M9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA
M;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@
M)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE
M?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA
M;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_
M<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I
M;&5N86UE(#T@7W-A=F5?87,H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U
M*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U
M:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1-;V1U;&5#86-H97LD9G5L;&YA;65]
M(#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN
M86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H
M<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F
M("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@9&5L971E("1R97%U
M:7)E7VQI<W1[)&UO9'5L97T@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@
M(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@
M86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&
M:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I
M;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB
M=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM
M>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN
M9F\M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O
M<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@
M)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@
M;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97([
M"G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M
M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D
M24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF
M("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M
M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@
M+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES
M='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP
M,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@
M("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@
M)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!
M4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U
M<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)5
M1WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P
M=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L
M:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS
M("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D
M05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%2
M7T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@
M<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@
M>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L
M87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]
M"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H
M)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H
M)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2![
M"B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N
M9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q
M.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R
M(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE
M;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H
M0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E
M("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$
M:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB
M4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N
M<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E
M($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z
M:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L
M("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D
M(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@
M<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5E;G8@/2!D;R![
M"FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!
M+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S
M+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]
M"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L
M("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D
M(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B
M(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P
M-"(["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/
M.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W
M-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T[
M"B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*
M:68@*&1E9FEN960@)&1A=&%?<&]S*2!["G)E860@7T9(+"`D;&]A9&5R+"`D
M9&%T85]P;W,["GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@
M/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E
M<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D
M97(L("0P*3L*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2![
M"FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V
M86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%2
M7R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D
M:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA
M9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T
M*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PII9B`H)&)U;F1L92D@
M>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I
M;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S
M:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A
M;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#
M.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD
M9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T
M<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG
M>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM
M>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S
M*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I
M;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I
M;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@
M;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D
M=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*
M;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@
M*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E
M9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@
M:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O
M:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F
M("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT
M.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*
M?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D9F@L("<\.G)A
M=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*
M)&-O;G1E;G0@/2`\)&9H/CL*8VQO<V4@)&9H.PI005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II
M9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI
M>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P
M;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)
M3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E
M,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I
M+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E
M;G0I.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*)'II<"T^
M=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]
M('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@
M86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@
M1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1O
M=70["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4@)&9H.PHD8V%C:&5?;F%M
M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@
M*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!
M0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C
M:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R
M:6YT*"1005)?34%'24,I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T
M.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?
M9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T
M97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@
M)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z
M.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E
M.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q
M<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C
M:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2
M.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]
M("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7%;7"1%
M3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P
M;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*
M;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE
M(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M
M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N
M?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*
M)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@
M1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?
M;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^
M=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB
M97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA
M;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N
M86UE(B!T;R`B)&1E<W1?;F%M92)=*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL
M94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I
M9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C
M:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A
M9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;
M('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T
M9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M
M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@
M*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A
M<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A
M<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL
M93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK
M<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*
M<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E
M9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER
M92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E
M($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`[
M"G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER
M92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL
M93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E
M(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#
M;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W
M9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!3
M8V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z
M.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T
M=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z
M.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?
M<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.
M5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U
M<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!0
M05)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<
M7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@
M86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D
M<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN
M960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*
M)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN
M960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S
M97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE3
M5$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@
M(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R
M;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,
M14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*
M;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PIS965K("1F:"P@+3$X+"`R.PIM
M>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#
M2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G)E860@)&9H+"`D8G5F+"`T,3L*
M)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M8V%C:&4M)&)U9B(["GT*96QS92!["FUY("1D:6=E<W0@/2!E=F%L"GL*<F5Q
M=6ER92!$:6=E<W0Z.E-(03L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H
M,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q
M6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*)&-T>"T^861D9FEL92@D
M9F@I.PIC;&]S92@D9F@I.PHD8W1X+3YH97AD:6=E<W0["GT@?'P@)&UT:6UE
M.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M)&1I9V5S="([
M"GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[
M4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL
M87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@
M*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@
M/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*
M;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G
M/CIR87<G+"`D=&5M<&YA;64@;W(@9&EE('%Q6T-A;B=T('=R:71E("(D=&5M
M<&YA;64B.B`D(5T["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*
M8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA
M;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I
M.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!2
M3T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N
M86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O
M9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U
M8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E
M;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E
M>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E
M;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@[
M"GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA
M;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D
M9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(
M?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E
M<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]
M7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE
M(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F
M:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/
M1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z
M.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R
M.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]
M?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG
M>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*
M<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$
M?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!
M3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"
M54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1?
M?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%
M3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI
M<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`]
M(")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6
M>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF
M("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E
M(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*
M)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%.
M/2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@
M*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN
M="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*
M<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[
M)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I
M=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K
M86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF
M:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP
M;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C
M:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID
M;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]
M("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ
M7U]%4E)/4CL*,3L*7U]%3D1?7PH``'!E<FQX<VDN8P!?7T5.5E]005)?0TQ%
M04Y?7R`@("`@("`@("`@("`@(``````!&P,[````T````!G__XW$```$T/__
MD<P```#L__^2?````2C__Y+$```!5/__DTP```&$__^4I````<#__Y4T```!
M\/__EVP```(L__^7K````DS__Y@,```"B/__F10```+$__^9'````MC__YKT
M```#%/__FQP```,H__^<1````TS__YW,```#>/__GCP```.D__^>;````\3_
M_Y\<```$$/__I60```1@__^G[```!)3__ZA4```%%/__OB0```50__^^E```
M!73__[_D```%L````!0``````7I2``%X#@$;#`^@`0```````#@````<__^0
MV````*X`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[``@*""L_.S<S+RLG(Q\8.
MH`%""P```"@```!8__^13````$(`1HL)C`B-!XX&CP5&#M`"=,_.S<S+#J`!
M````````+````(3__Y%H````A@!&B0N*"HL)C`B-!XX&CP5&#M`"`GC/SLW,
MR\K)#J`!````.````+3__Y'````!6`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&
M#M@#`P%*S\[-S,O*R<C'Q@Z@`0``````+````/#__Y+<````D`!&B@J+"8P(
MC0>.!H\%1@[8`P*"S\[-S,O*#J`!````````.````2#__Y,\```",@!&A@Z'
M#8@,B0N*"HL)C`B-!XX&CP5&#M`"`P(DS\[-S,O*R<C'Q@Z@`0``````'```
M`5S__Y4X````/`!,C@:/!48.P`)DS\X.H`$````X```!?/__E5@```!:`$:&
M#H<-B`R)"XH*BPF,"(T'C@:/!48.R`("3,_.S<S+RLG(Q\8.H`$````````X
M```!N/__E7P```$$`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.T$("]L_.S<S+
MRLG(Q\8.H`$````````0```!]/__ED@````&`````````#@```((__^6/```
M`=8`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[@(P,!R,_.S<S+RLG(Q\8.H`$`
M`````!````)$__^7V````"(`````````(````EC__Y?L```!(@`"XHX&CP5&
M#L`"7L_.#J`!````````*````GS__YCP```!@@!,BPF,"(T'C@:/!48.\`(#
M`6[/SLW,RPZ@`0`````H```"J/__FDP```!N`%J.!H\%1@[``G8*S\X.H`%(
M"T@.H`'.SP```````!P```+4__^:D````"P`1HX&CP5&#L`"7L_.#J`!````
M2````O3__YJ@````K`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5*#L`";@K/SLW,
MR\K)R,?&#J`!1@L"9L_.S<S+RLG(Q\8.H`$``````$P```-`__^;!```!D(`
M1H8.APV(#(D+B@J+"8P(C0>.!H\%1@Z(A0("A@K/SLW,R\K)R,?&#J`!1@L#
M`;X*S\[-S,O*R<C'Q@Z@`4(+````,````Y#__Z#\```"A`!&B0N*"HL)C`B-
M!XX&CP5&#L`"`P)VS\[-S,O*R0Z@`0```````#@```/$__^C4````&@`1HH*
MBPF,"(T'C@:/!48.P`("3@K/SLW,R\H.H`%&"T;/SLW,R\H.H`$``````$``
M``0`__^([````?P`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[8`@,!V`K/SLW,
MR\K)R,?&#J`!0@L`````````````.```!$3__Z,X```5T`!8A@Z'#8@,B0N*
M"HL)C`B-!XX&CP5&#M`'`Q6PS\[-S,O*R<C'Q@Z@`0``````(```!(#__[C,
M````;`!*C@:/!48.P`("6L_.#J`!````````.```!*3__[D8```!3@!,A@Z'
M#8@,B0N*"HL)C`B-!XX&CP5>#L`"`N(*S\[-S,O*R<C'Q@Z@`4(+````-```
M!.#__[HL```!%@!&B`R)"XH*BPF,"(T'C@:/!6X.P`("N`K/SLW,R\K)R`Z@
M`48+````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#__________P``````````__________\````````````````````!
M`````````M(``````````0````````+=``````````\````````$!P``````
M```,````````%Y@`````````#0```````%)P`````&___O4````````"&```
M```````%````````"\``````````!@````````+P``````````H````````$
M)0`````````+`````````!@`````````%0````````````````````,`````
M``"ML``````````"````````!4``````````%``````````'`````````!<`
M```````26``````````'````````#^@`````````"`````````)P````````
M``D`````````&``````````8````````````````;___^P`````(```!````
M`&____D`````````#@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````K!``````````````````````````````%^X````````8#@``
M`````!@N````````&$X````````8;@```````!B.````````&*X````````8
MS@```````!CN````````&0X````````9+@```````!E.````````&6X`````
M```9C@```````!FN````````&<X````````9[@```````!H.````````&BX`
M```````:3@```````!IN````````&HX````````:K@```````!K.````````
M&NX````````;#@```````!LN````````&TX````````;;@```````!N.````
M````&ZX````````;S@```````!ON````````'`X````````<+@```````!Q.
M````````'&X````````<C@```````!RN````````',X````````<[@``````
M`!T.````````'2X````````=3@```````!UN````````'8X````````=K@``
M`````!W.````````'>X````````>#@```````!XN````````'DX````````>
M;@```````!Z.````````'JX````````>S@```````![@````````````````
M`````````````%)P`````````````````````````````!>8````````````
M````````````````````````````````````````````````````````````
M`````````````````````+``_____P````````````!2D@```````%*8````
M``````````````!2F@```````%*>````````4J8```````!3$@```````%*N
M``````````````````!2L@```````%*X``````````````````!5;D=#0SH@
M*$%L<&EN92`Q,"XS+C%?9VET,C`R,3`Y,C$I(#$P+C,N,2`R,#(Q,#DR,0``
M+G-H<W1R=&%B`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N
M<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`
M+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N9'EN86UI
M8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````````
M````````````````````````````````````````````````````````````
M```````````+`````0`````````"`````````@`````````"```````````8
M`````````````````````0``````````````$V____8``````````@``````
M``(8`````````A@`````````V`````,```````````````@`````````````
M`!T````+``````````(````````"\`````````+P````````"-`````$````
M`@`````````(`````````!@````E`````P`````````"````````"\``````
M```+P`````````0E`````````````````````0``````````````+0````0`
M`````````@````````_H````````#^@````````"<`````,`````````````
M``@`````````&````#<````$`````````$(````````26````````!)8````
M````!4`````#````$0`````````(`````````!@```!!`````0`````````&
M````````%Y@````````7F``````````H`````````````````````@``````
M````````/`````$`````````!@```````!?`````````%\`````````'(```
M``````````````````0`````````(````$<````!``````````8````````>
MX````````![@````````,Y`````````````````````(``````````````!-
M`````0`````````&````````4G````````!2<``````````B````````````
M`````````@``````````````4P````$``````````@```````%*2````````
M4I(````````^B`````````````````````(``````````````%L````!````
M``````(```````"1'````````)$<`````````-0````````````````````$
M``````````````!I`````0`````````"````````D?````````"1\```````
M``48````````````````````"```````````````<P````$``````````P``
M`````*OP````````F_``````````$`````````````````````@`````````
M`````'H````!``````````,```````"L`````````)P``````````!``````
M```````````````(``````````````"!````!@`````````#````````K!``
M``````"<$`````````&@````!```````````````"``````````0````B@``
M``$``````````P```````*VP````````G;`````````"4```````````````
M``````@`````````"````(\````!``````````,```````"P`````````*``
M`````````'@````````````````````(``````````````"5````"```````
M```#````````L'@```````"@>````````!!@````````````````````"```
M````````````F@````$`````````,```````````````````H'@`````````
M,0````````````````````$``````````0````$````#````````````````
L`````````````*"I`````````*,````````````````````!````````````
